;;; quail/cyrillic.el -- Quail package for inputting Cyrillic characters

;; Copyright (C) 1997 Electrotechnical Laboratory, JAPAN.
;; Licensed to the Free Software Foundation.

;; Keywords: multilingual, input method, Cyrillic

;; This file is part of GNU Emacs.

;; GNU Emacs is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; GNU Emacs is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with GNU Emacs; see the file COPYING.  If not, write to the
;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.

;;; Code:

(require 'quail)

(quail-define-package
 "cyrillic-jcuken" "Cyrillic" "" nil
 "ú keyboard layout widely used in Russia (ISO 8859-5 encoding)"
 nil t t t t)

;;  1! 2@ 3# 4" 5: 6, 7. 8* 9( 0) -_ =+ 
;;                         
;;                       
;;                       /?

(quail-define-rules
 ("1" ?1)
 ("2" ?2)
 ("3" ?3)
 ("4" ?4)
 ("5" ?5)
 ("6" ?6)
 ("7" ?7)
 ("8" ?8)
 ("9" ?9)
 ("0" ?0)
 ("-" ?-)
 ("=" ?=)
 ("`" ?)
 ("q" ?)
 ("w" ?)
 ("e" ?)
 ("r" ?)
 ("t" ?)
 ("y" ?)
 ("u" ?)
 ("i" ?)
 ("o" ?)
 ("p" ?)
 ("[" ?)
 ("]" ?)
 ("a" ?)
 ("s" ?)
 ("d" ?)
 ("f" ?)
 ("g" ?)
 ("h" ?)
 ("j" ?)
 ("k" ?)
 ("l" ?)
 (";" ?)
 ("'" ?)
 ("\\" ?\\)
 ("z" ?)
 ("x" ?)
 ("c" ?)
 ("v" ?)
 ("b" ?)
 ("n" ?)
 ("m" ?)
 ("," ?)
 ("." ?)
 ("/" ?/)
 
 ("!" ?!)
 ("@" ?@)
 ("#" ?#)
 ("$" ?\")
 ("%" ?:)
 ("^" ?,)
 ("&" ?.)
 ("*" ?*)
 ("(" ?()
  (")" ?))
 ("_" ?_)
 ("+" ?+)
 ("~" ?)
 ("Q" ?)
 ("W" ?)
 ("E" ?)
 ("R" ?)
 ("T" ?)
 ("Y" ?)
 ("U" ?)
 ("I" ?)
 ("O" ?)
 ("P" ?)
 ("{" ?)
 ("}" ?)
 ("A" ?)
 ("S" ?)
 ("D" ?)
 ("F" ?)
 ("G" ?)
 ("H" ?)
 ("J" ?)
 ("K" ?)
 ("L" ?)
 (":" ?)
 ("\"" ?)
 ("|" ?|)
 ("Z" ?)
 ("X" ?)
 ("C" ?)
 ("V" ?)
 ("B" ?)
 ("N" ?)
 ("M" ?)
 ("<" ?)
 (">" ?)
 ("?" ??))

;;

(quail-define-package
 "cyrillic-jis-russian" "Cyrillic" "$(B'('+(B" nil
 "$(B'+'8'5','&'/(B keyboard layout same as JCUKEN (JIS X0208.1983 encoding)"
		      nil t t t t)

;;  1! 2@ 3# 4" 5: 6, 7. 8* 9( 0) -_ =+ 
;;                         
;;                        
;;                       /?

(quail-define-rules
 ("1" ?$(B#1(B)
 ("2" ?$(B#2(B)
 ("3" ?$(B#3(B)
 ("4" ?$(B#4(B)
 ("5" ?$(B#5(B)
 ("6" ?$(B#6(B)
 ("7" ?$(B#7(B)
 ("8" ?$(B#8(B)
 ("9" ?$(B#9(B)
 ("0" ?$(B#0(B)
 ("-" ?$(B!](B)
 ("=" ?$(B!a(B)
 ("`" ?$(B'W(B)
 ("q" ?$(B'[(B)
 ("w" ?$(B'h(B)
 ("e" ?$(B'e(B)
 ("r" ?$(B'\(B)
 ("t" ?$(B'V(B)
 ("y" ?$(B'_(B)
 ("u" ?$(B'T(B)
 ("i" ?$(B'j(B)
 ("o" ?$(B'k(B)
 ("p" ?$(B'Y(B)
 ("[" ?$(B'g(B)
 ("]" ?$(B'l(B)
 ("a" ?$(B'f(B)
 ("s" ?$(B'm(B)
 ("d" ?$(B'S(B)
 ("f" ?$(B'Q(B)
 ("g" ?$(B'a(B)
 ("h" ?$(B'b(B)
 ("j" ?$(B'`(B)
 ("k" ?$(B'](B)
 ("l" ?$(B'U(B)
 (";" ?$(B'X(B)
 ("'" ?$(B'o(B)
 ("\\" ?$(B!@(B)
 ("z" ?$(B'q(B)
 ("x" ?$(B'i(B)
 ("c" ?$(B'c(B)
 ("v" ?$(B'^(B)
 ("b" ?$(B'Z(B)
 ("n" ?$(B'd(B)
 ("m" ?$(B'n(B)
 ("," ?$(B'R(B)
 ("." ?$(B'p(B)
 ("/" ?$(B!?(B)
 
 ("!" ?$(B!*(B)
 ("@" ?$(B!w(B)
 ("#" ?$(B!t(B)
 ("$" ?$(B!I(B)
 ("%" ?$(B!'(B)
 ("^" ?$(B!$(B)
 ("&" ?$(B!%(B)
 ("*" ?$(B!v(B)
 ("(" ?$(B!J(B)
  (")" ?$(B!K(B)
 ("_" ?$(B!2(B)
 ("+" ?$(B!\(B)
 ("~" ?$(B''(B)
 ("Q" ?$(B'+(B)
 ("W" ?$(B'8(B)
 ("E" ?$(B'5(B)
 ("R" ?$(B',(B)
 ("T" ?$(B'&(B)
 ("Y" ?$(B'/(B)
 ("U" ?$(B'$(B)
 ("I" ?$(B':(B)
 ("O" ?$(B';(B)
 ("P" ?$(B')(B)
 ("{" ?$(B'7(B)
 ("}" ?$(B'<(B)
 ("A" ?$(B'6(B)
 ("S" ?$(B'=(B)
 ("D" ?$(B'#(B)
 ("F" ?$(B'!(B)
 ("G" ?$(B'1(B)
 ("H" ?$(B'2(B)
 ("J" ?$(B'0(B)
 ("K" ?$(B'-(B)
 ("L" ?$(B'%(B)
 (":" ?$(B'((B)
 ("\"" ?$(B'?(B)
 ("|" ?$(B!C(B)
 ("Z" ?$(B'A(B)
 ("X" ?$(B'9(B)
 ("C" ?$(B'3(B)
 ("V" ?$(B'.(B)
 ("B" ?$(B'*(B)
 ("N" ?$(B'4(B)
 ("M" ?$(B'>(B)
 ("<" ?$(B'"(B)
 (">" ?$(B'@(B)
 ("?" ?$(B!)(B))

;;

(quail-define-package
 "cyrillic-macedonian" "Cyrillic" "M" nil
 "·- keyboard layout based on JUS.I.K1.004 (ISO 8859-5 encoding)"
 nil t t t t)

;;  1! 2" 3# 4$ 5% 6& 7' 8( 9) 0= /? +* <>
;;                         
;;                          
;;                   ,; .: -_

(quail-define-rules
 ("1" ?1)
 ("2" ?2)
 ("3" ?3)
 ("4" ?4)
 ("5" ?5)
 ("6" ?6)
 ("7" ?7)
 ("8" ?8)
 ("9" ?9)
 ("0" ?0)
 ("-" ?/)
 ("=" ?+)
 ("`" ?<)
 ("q" ?)
 ("w" ?)
 ("e" ?)
 ("r" ?)
 ("t" ?)
 ("y" ?)
 ("u" ?)
 ("i" ?)
 ("o" ?)
 ("p" ?)
 ("[" ?)
 ("]" ?)
 ("a" ?)
 ("s" ?)
 ("d" ?)
 ("f" ?)
 ("g" ?)
 ("h" ?)
 ("j" ?)
 ("k" ?)
 ("l" ?)
 (";" ?)
 ("'" ?)
 ("\\" ?)
 ("z" ?)
 ("x" ?)
 ("c" ?)
 ("v" ?)
 ("b" ?)
 ("n" ?)
 ("m" ?)
 ("," ?,)
 ("." ?.)
 ("/" ?-)
 
 ("!" ?!)
 ("@" ?\")
 ("#" ?#)
 ("$" ?$)
 ("%" ?%)
 ("^" ?&)
 ("&" ?')
 ("*" ?\()
 ("(" ?\))
 (")" ?=)
 ("_" ??)
 ("+" ?*)
 ("~" ?>)
 ("Q" ?)
 ("W" ?)
 ("E" ?)
 ("R" ?)
 ("T" ?)
 ("Y" ?)
 ("U" ?)
 ("I" ?)
 ("O" ?)
 ("P" ?)
 ("{" ?)
 ("}" ?)
 ("A" ?)
 ("S" ?)
 ("D" ?)
 ("F" ?)
 ("G" ?)
 ("H" ?)
 ("J" ?)
 ("K" ?)
 ("L" ?)
 (":" ?)
 ("\"" ?)
 ("|" ?)
 ("Z" ?)
 ("X" ?)
 ("C" ?)
 ("V" ?)
 ("B" ?)
 ("N" ?)
 ("M" ?)
 ("<" ?\;)
 (">" ?:)
 ("?" ?_))

;;

(quail-define-package
 "cyrillic-serbian" "Cyrillic" "S" nil
 "·- keyboard layout based on JUS.I.K1.005 (ISO 8859-5 encoding)"
		      nil t t t t)

;;  1! 2" 3# 4$ 5% 6& 7' 8( 9) 0= /? +* <>
;;                         
;;                          
;;                   ,; .: -_

(quail-define-rules
 ("1" ?1)
 ("2" ?2)
 ("3" ?3)
 ("4" ?4)
 ("5" ?5)
 ("6" ?6)
 ("7" ?7)
 ("8" ?8)
 ("9" ?9)
 ("0" ?0)
 ("-" ?/)
 ("=" ?+)
 ("`" ?<)
 ("q" ?)
 ("w" ?)
 ("e" ?)
 ("r" ?)
 ("t" ?)
 ("y" ?)
 ("u" ?)
 ("i" ?)
 ("o" ?)
 ("p" ?)
 ("[" ?)
 ("]" ?)
 ("a" ?)
 ("s" ?)
 ("d" ?)
 ("f" ?)
 ("g" ?)
 ("h" ?)
 ("j" ?)
 ("k" ?)
 ("l" ?)
 (";" ?)
 ("'" ?)
 ("\\" ?)
 ("z" ?)
 ("x" ?)
 ("c" ?)
 ("v" ?)
 ("b" ?)
 ("n" ?)
 ("m" ?)
 ("," ?,)
 ("." ?.)
 ("/" ?-)
 
 ("!" ?!)
 ("@" ?\")
 ("#" ?#)
 ("$" ?$)
 ("%" ?%)
 ("^" ?&)
 ("&" ?')
 ("*" ?\()
 ("(" ?\))
 (")" ?=)
 ("_" ??)
 ("+" ?*)
 ("~" ?>)
 ("Q" ?)
 ("W" ?)
 ("E" ?)
 ("R" ?)
 ("T" ?)
 ("Y" ?)
 ("U" ?)
 ("I" ?)
 ("O" ?)
 ("P" ?)
 ("{" ?)
 ("}" ?)
 ("A" ?)
 ("S" ?)
 ("D" ?)
 ("F" ?)
 ("G" ?)
 ("H" ?)
 ("J" ?)
 ("K" ?)
 ("L" ?)
 (":" ?)
 ("\"" ?)
 ("|" ?)
 ("Z" ?)
 ("X" ?)
 ("C" ?)
 ("V" ?)
 ("B" ?)
 ("N" ?)
 ("M" ?)
 ("<" ?\;)
 (">" ?:)
 ("?" ?_))

;;

(quail-define-package
 "cyrillic-beylorussian" "Cyrillic" "B" nil
 "·- BEYLORUSSIAN (ISO 8859-5 encoding)"
 nil t t t t)

;;  1! 2" 3# 4$ 5% 6& 7' 8( 9) 0= /? +* <>
;;                         
;;                          
;;                   ,; .: -_

(quail-define-rules
 ("1" ?1)
 ("2" ?2)
 ("3" ?3)
 ("4" ?4)
 ("5" ?5)
 ("6" ?6)
 ("7" ?7)
 ("8" ?8)
 ("9" ?9)
 ("0" ?0)
 ("-" ?/)
 ("=" ?+)
 ("`" ?<)
 ("q" ?)
 ("w" ?)
 ("e" ?)
 ("r" ?)
 ("t" ?)
 ("y" ?)
 ("u" ?)
 ("i" ?)
 ("o" ?)
 ("p" ?)
 ("[" ?)
 ("]" ?)
 ("a" ?)
 ("s" ?)
 ("d" ?)
 ("f" ?)
 ("g" ?)
 ("h" ?)
 ("j" ?)
 ("k" ?)
 ("l" ?)
 (";" ?)
 ("'" ?)
 ("\\" ?)
 ("z" ?)
 ("x" ?)
 ("c" ?)
 ("v" ?)
 ("b" ?)
 ("n" ?)
 ("m" ?)
 ("," ?,)
 ("." ?.)
 ("/" ?-)
 
 ("!" ?!)
 ("@" ?\")
 ("#" ?#)
 ("$" ?$)
 ("%" ?%)
 ("^" ?&)
 ("&" ?')
 ("*" ?\()
 ("(" ?\))
 (")" ?=)
 ("_" ??)
 ("+" ?*)
 ("~" ?>)
 ("Q" ?)
 ("W" ?)
 ("E" ?)
 ("R" ?)
 ("T" ?)
 ("Y" ?)
 ("U" ?)
 ("I" ?)
 ("O" ?)
 ("P" ?)
 ("{" ?)
 ("}" ?)
 ("A" ?)
 ("S" ?)
 ("D" ?)
 ("F" ?)
 ("G" ?)
 ("H" ?)
 ("J" ?)
 ("K" ?)
 ("L" ?)
 (":" ?)
 ("\"" ?)
 ("|" ?)
 ("Z" ?)
 ("X" ?)
 ("C" ?)
 ("V" ?)
 ("B" ?)
 ("N" ?)
 ("M" ?)
 ("<" ?\;)
 (">" ?:)
 ("?" ?_))

;;

(quail-define-package 
 "cyrillic-ukrainian" "Cyrillic" "U" nil
 "·- UKRAINIAN (ISO 8859-5 encoding)

Sorry, but 'ghe with upturn' is not included in ISO 8859-5"
 nil t t t t)

;;  1! 2" 3# 4$ 5% 6& 7' 8( 9) 0= /? +* <>
;;                         
;;                          
;;                   ,; .: -_

(quail-define-rules
 ("1" ?1)
 ("2" ?2)
 ("3" ?3)
 ("4" ?4)
 ("5" ?5)
 ("6" ?6)
 ("7" ?7)
 ("8" ?8)
 ("9" ?9)
 ("0" ?0)
 ("-" ?/)
 ("=" ?+)
 ("`" ?<)
 ("q" ?)
 ("w" ?)
 ("e" ?)
 ("r" ?)
 ("t" ?)
 ("y" ?)
 ("u" ?)
 ("i" ?)
 ("o" ?)
 ("p" ?)
 ("[" ?)
 ("]" ?)
 ("a" ?)
 ("s" ?)
 ("d" ?)
 ("f" ?)
 ("g" ?)
 ("h" ?)
 ("j" ?)
 ("k" ?)
 ("l" ?)
 (";" ?)
 ("'" ?)
 ("\\" ?)
 ("z" ?)
 ("x" ?)
 ("c" ?)
 ("v" ?)
 ("b" ?)
 ("n" ?)
 ("m" ?)
 ("," ?,)
 ("." ?.)
 ("/" ?-)
 
 ("!" ?!)
 ("@" ?\")
 ("#" ?#)
 ("$" ?$)
 ("%" ?%)
 ("^" ?&)
 ("&" ?')
 ("*" ?\()
 ("(" ?\))
 (")" ?=)
 ("_" ??)
 ("+" ?*)
 ("~" ?>)
 ("Q" ?)
 ("W" ?)
 ("E" ?)
 ("R" ?)
 ("T" ?)
 ("Y" ?)
 ("U" ?)
 ("I" ?)
 ("O" ?)
 ("P" ?)
 ("{" ?)
 ("}" ?)
 ("A" ?)
 ("S" ?)
 ("D" ?)
 ("F" ?)
 ("G" ?)
 ("H" ?)
 ("J" ?)
 ("K" ?)
 ("L" ?)
 (":" ?)
 ("\"" ?)
 ("|" ?)
 ("Z" ?)
 ("X" ?)
 ("C" ?)
 ("V" ?)
 ("B" ?)
 ("N" ?)
 ("M" ?)
 ("<" ?\;)
 (">" ?:)
 ("?" ?_))

;;

(quail-define-package 
 "cyrillic-yawerty" "Cyrillic" "" nil
 "ϲ Roman transcription (ISO 8859-5 encoding)

This layout is based on Roman transcription.
When preceded by a '/', the second and the third rows (number key row) change
as follows.

  keytop | Q  W  E  R  T  Y  U  I  O  P  A  S  D
 --------+---------------------------------------
  input  |                         "
		      nil t t t t)

;;  1! 2 3 4 5% 6^ 7& 8* 9( 0) -_   
;;                         
;;                      ;: '" 
;;                   ,< .> /?

;;  1! 2 3 4 5% 6^ 7& 8* 9( 0) -_   
;;                         
;;                      ;: '" 
;;                   ,< .> /?

(quail-define-rules
 ("1" ?1)
 ("2" ?2)
 ("3" ?3)
 ("4" ?4)
 ("5" ?5)
 ("6" ?6)
 ("7" ?7)
 ("8" ?8)
 ("9" ?9)
 ("0" ?0)
 ("-" ?-)
 ("=" ?)
 ("`" ?)
 ("q" ?)
 ("w" ?)
 ("e" ?)
 ("r" ?)
 ("t" ?)
 ("y" ?)
 ("u" ?)
 ("i" ?)
 ("o" ?)
 ("p" ?)
 ("[" ?)
 ("]" ?)
 ("a" ?)
 ("s" ?)
 ("d" ?)
 ("f" ?)
 ("g" ?)
 ("h" ?)
 ("j" ?)
 ("k" ?)
 ("l" ?)
 (";" ?\;)
 ("'" ?')
 ("\\" ?)
 ("z" ?)
 ("x" ?)
 ("c" ?)
 ("v" ?)
 ("b" ?)
 ("n" ?)
 ("m" ?)
 ("," ?,)
 ("." ?.)
 ("/" ?/)
 
 ("!" ?!)
 ("@" ?)
 ("#" ?)
 ("$" ?)
 ("%" ?%)
 ("^" ?^)
 ("&" ?&)
 ("*" ?*)
 ("(" ?\()
 (")" ?\))
 ("_" ?_)
 ("+" ?)
 ("~" ?)
 ("Q" ?)
 ("W" ?)
 ("E" ?)
 ("R" ?)
 ("T" ?)
 ("Y" ?)
 ("U" ?)
 ("I" ?)
 ("O" ?)
 ("P" ?)
 ("{" ?)
 ("}" ?)
 ("A" ?)
 ("S" ?)
 ("D" ?)
 ("F" ?)
 ("G" ?)
 ("H" ?)
 ("J" ?)
 ("K" ?)
 ("L" ?)
 (":" ?:)
 ("\"" ?\")
 ("|" ?)
 ("Z" ?)
 ("X" ?)
 ("C" ?)
 ("V" ?)
 ("B" ?)
 ("N" ?)
 ("M" ?)
 ("<" ?<)
 (">" ?>)
 ("?" ??)
 
 ("/q" ?)
 ("/w" ?)
 ("/e" ?)
 ("/r" ?)
 ("/t" ?)
 ("/y" ?)
 ("/u" ?)
 ("/i" ?)
 ("/o" ?)
 ("/p" ?)
 ("/a" ?)
 ("/s" ?)
 ("/d" ?)
 
 ("/Q" ?)
 ("/W" ?)
 ("/E" ?)
 ("/R" ?)
 ("/T" ?)
 ("/Y" ?)
 ("/U" ?)
 ("/I" ?)
 ("/O" ?)
 ("/P" ?)
 ("/A" ?)
 ("/S" ?)
 ("/D" ?))

;; This was provided by Valery Alexeev <valery@domovoy.math.uga.edu>.

(quail-define-package
 "cyrillic-translit" "Cyrillic" "t" nil
 "Intuitively transliterated keybooard layout.
Most convenient for entering Russian but all cyrillic characters are included.
Should handle most cases. However:
  for TSE use \"c\", never \"ts\"
  SHCHA = Bulgarian SHT = \"shch\", \"sj\", \"\\sht\" or \"\\t\",
  REVERSE ROUNDED E = \"e'\" or \"e`\"
  KHA when after  \"c,s,z\" = \"x\" or \"kh\"
  HARD SIGN = \"~\", CAPITAL HARD SIGN = \"~~\",
  SOFT SIGN = \"'\", CAPITAL SOFT SIGN = \"''\".

Also included are Ukranian YE = \"\\e\" and YI = \"yi\", 
Belorussian SHORT U = \"u'\",
Serbocroatian DJE = \"\\d\", CHJE= \"\\ch\", 
Macedonian GJE = \"\\g\", DZE = \"\\s\", KJE = \"\\k\",
cyrillic I DECIMAL = \"\\i\", JE = \"\\j\", LJE = \"\\l\", NJE = \"\\n\" and DZE =\"\\z\"."
 nil t t t t)

(quail-define-rules
 ("a" ?)("b" ?) ("v" ?) ("w" ?) ("g" ?) ("d" ?) 
 ("e" ?) ("je" ?) ("je" ?)
 ("yo" ?) ("jo" ?)
 ("zh" ?) ("z" ?) ("i" ?) 
 ("j" ?) ("j'" ?) ("j`" ?) ("k" ?) ("l" ?)
 ("m" ?) ("n" ?) ("o" ?) ("p" ?) ("r" ?) ("s" ?) ("t" ?) ("u" ?)
 ("f" ?) ("x" ?) ("h" ?) ("kh" ?)
 ("c" ?) ("ch" ?)
 ("sh" ?) 
; ("w" ?) ("q" ?) 
 ("shch" ?) ("sj" ?) 
 ("\\sht" ?) ("\\t" ?) 
 ("~" ?) ("y" ?) ("'" ?) ("`" ?) 
 ("e'" ?) ("e`" ?) ("@" ?) 
 ("yu" ?) ("ju" ?) 
 ("ya" ?) ("ja" ?)

 ("A" ?) ("B" ?) ("V" ?) ("W" ?) ("G" ?) ("D" ?) 
 ("E" ?) ("Je" ?) ("JE" ?)
 ("Yo" ?) ("YO" ?) ("Jo" ?) ("JO" ?) 
 ("Zh" ?) ("ZH" ?) ("Z" ?) ("I" ?) 
 ("J" ?) ("J'" ?) ("J`" ?) ("K" ?) ("L" ?)
 ("M" ?) ("N" ?) ("O" ?) ("P" ?) ("R" ?) ("S" ?) ("T" ?) ("U" ?)
 ("F" ?) ("X" ?) ("H" ?) ("Kh" ?) ("KH" ?)
 ("C" ?) ("Ch" ?) ("CH" ?) 
 ("Sh" ?) ("SH" ?) 
; ("W" ?) ("Q" ?) 
 ("Shch" ?) ("SHCH" ?) ("Sj" ?) ("SJ" ?) 
 ("\\Sht" ?) ("\\SHT" ?) ("\\T" ?) 
 ("~~" "") ("Y" ?) ("''" "") ("E'" ?) ("E`" ?) 
 ("Yu" ?) ("YU" ?) ("Ju" ?) ("JU" ?) 
 ("Ya" ?) ("YA" ?) ("Ja" ?) ("JA" ?) 

 ("\\e" ?) ("yi" ?) ("u'" ?)
 ("\\d" ?) ("\\ch" ?)
 ("\\g" ?) ("\\s" ?) ("\\k" ?)
 ("\\i" ?) ("\\j" ?) ("\\l" ?) ("\\n" ?) ("\\z" ?)
 ("\\E" ?) ("YE" ?) ("Yi" ?) ("YI" ?) ("U'" ?) 
 ("\\D" ?) ("\\Ch" ?) ("\\CH" ?)
 ("\\G" ?) ("\\S" ?) ("\\K" ?) 
 ("\\I" ?) ("\\J" ?) ("\\L" ?) ("\\N" ?) ("\\Z" ?)
)

;; Local Variables:
;; buffer-file-coding-system: cyrillic-iso-8bit
;; End:

